# time-mclust

Package accompanying code from senior thesis Spring 2021 at Harvard College in Computer Science and Statistics

Also includes a helper class for fetching tweets given a valid bearer token for the Twitter API
